@@ -3,7 +3,7 @@ from django.core.management import call_command
 
 
 class Command(BaseCommand):
-    help = 'Lint JavaScript and Python files'
+    help = "Lint JavaScript and Python files"
 
     def handle(self, *args, **options):
         call_command("lint_js")
