@@ -8,15 +8,15 @@ from django.conf import settings
 
 
 class Command(BaseCommand):
-    help = 'Check CSS files with Stylelint'
+    help = "Check CSS files with Stylelint"
 
     def add_arguments(self, parser):
         parser.add_argument(
-            '--fix',
-            action='store_true',
-            dest='fix',
+            "--fix",
+            action="store_true",
+            dest="fix",
             default=False,
-            help='Whether to also attempt to fix files'
+            help="Whether to also attempt to fix files",
         )
 
     def handle(self, *args, **options):
@@ -25,8 +25,7 @@ class Command(BaseCommand):
         shutil.os.chdir(settings.PROJECT_PATH)
         command_array = [
             os.path.join(
-                settings.PROJECT_PATH,
-                ".transpile/node_modules/.bin/stylelint"
+                settings.PROJECT_PATH, ".transpile/node_modules/.bin/stylelint"
             ),
             "**/*.css",
             "!static-libs/**",
@@ -34,14 +33,10 @@ class Command(BaseCommand):
             "!venv/**",
             "--allow-empty-input",
             "--config",
-            os.path.join(
-                settings.SRC_PATH,
-                "stylelint.config.js"
-            )
-
+            os.path.join(settings.SRC_PATH, "stylelint.config.js"),
         ]
-        if options['fix']:
-            command_array.append('--fix')
+        if options["fix"]:
+            command_array.append("--fix")
         return_value = call(command_array)
         if return_value > 0:
             exit(return_value)
