@@ -7,8 +7,6 @@ from django.views.decorators.http import require_POST
 
 from allauth.socialaccount.models import providers
 
-from user import util as userutil
-
 from .decorators import ajax_required
 from . import get_version
 
@@ -19,14 +17,14 @@ def app(request):
     Load a page controlled by the JavaScript app.
     Used all user facing pages after login.
     """
-    return render(request, 'app.html', {'version': get_version()})
+    return render(request, "app.html", {"version": get_version()})
 
 
 def api_404(request):
     """
     Show a 404 error within the API.
     """
-    return render(request, 'api_404.html', status=404)
+    return render(request, "api_404.html", status=404)
 
 
 @ajax_required
@@ -37,64 +35,64 @@ def configuration(request):
     """
     socialaccount_providers = []
     for provider in providers.registry.get_list():
-        socialaccount_providers.append({
-            'id': provider.id,
-            'name': provider.name,
-            'login_url': provider.get_login_url(request)
-        })
+        socialaccount_providers.append(
+            {
+                "id": provider.id,
+                "name": provider.name,
+                "login_url": provider.get_login_url(request),
+            }
+        )
     response = {
-        'language': request.LANGUAGE_CODE,
-        'socialaccount_providers': socialaccount_providers
+        "language": request.LANGUAGE_CODE,
+        "socialaccount_providers": socialaccount_providers,
     }
     if request.user.is_authenticated:
-        response['user'] = {
-            'id': request.user.id,
-            'username': request.user.username,
-            'first_name': request.user.first_name,
-            'name': request.user.readable_name,
-            'last_name': request.user.last_name,
-            'avatar': userutil.get_user_avatar_url(request.user),
-            'emails': [],
-            'socialaccounts': [],
-            'is_authenticated': True
+        response["user"] = {
+            "id": request.user.id,
+            "username": request.user.username,
+            "first_name": request.user.first_name,
+            "name": request.user.readable_name,
+            "last_name": request.user.last_name,
+            "avatar": request.user.avatar_url,
+            "emails": [],
+            "socialaccounts": [],
+            "is_authenticated": True,
         }
 
         for emailaddress in request.user.emailaddress_set.all():
             email = {
-                'address': emailaddress.email,
+                "address": emailaddress.email,
             }
             if emailaddress.primary:
-                email['primary'] = True
+                email["primary"] = True
             if emailaddress.verified:
-                email['verified'] = True
-            response['user']['emails'].append(email)
+                email["verified"] = True
+            response["user"]["emails"].append(email)
         for account in request.user.socialaccount_set.all():
             try:
                 provider_account = account.get_provider_account()
-                response['user']['socialaccounts'].append({
-                    'id': account.id,
-                    'provider': account.provider,
-                    'name': provider_account.to_str()
-                })
+                response["user"]["socialaccounts"].append(
+                    {
+                        "id": account.id,
+                        "provider": account.provider,
+                        "name": provider_account.to_str(),
+                    }
+                )
             except KeyError:
                 # Social account provider has been removed.
                 pass
+        response["user"]["waiting_invites"] = request.user.invites_to.exists()
 
     else:
-        response['user'] = {
-            'is_authenticated': False
-        }
-    return JsonResponse(
-        response,
-        status=200
-    )
+        response["user"] = {"is_authenticated": False}
+    return JsonResponse(response, status=200)
 
 
 def manifest_json(request):
     """
     Load the manifest.json.
     """
-    return render(request, 'manifest.json')
+    return render(request, "manifest.json")
 
 
 # view is shown only in admin interface, so authentication is taken care of
@@ -102,7 +100,7 @@ def admin_console(request):
     """
     Load the admin console page.
     """
-    return render(request, 'admin/console.html')
+    return render(request, "admin/console.html")
 
 
 @ajax_required
@@ -116,14 +114,11 @@ def flatpage(request):
     """
     response = {}
     status = 404
-    url = request.POST['url']
+    url = request.POST["url"]
     site_id = get_current_site(request).id
     flatpage = FlatPage.objects.filter(url=url, sites=site_id).first()
     if flatpage:
         status = 200
-        response['title'] = flatpage.title
-        response['content'] = flatpage.content
-    return JsonResponse(
-        response,
-        status=status
-    )
+        response["title"] = flatpage.title
+        response["content"] = flatpage.content
+    return JsonResponse(response, status=status)
