@@ -98,15 +98,15 @@ export class RangeFieldForm {
 
     get value() {
         if (this.range) {
-                if (
-                    !this.fields.from.value &&
+            if (
+                !this.fields.from.value &&
                     !this.fields.to.value
-                ) {
-                    return false
-                }
+            ) {
+                return false
+            }
             return [
-                this.fields.from.value ? this.fields.from.value : '',
-                this.fields.to.value ? this.fields.to.value : ''
+                this.fields.from.value ? this.fields.from.value : [{type: 'text', text: ''}],
+                this.fields.to.value ? this.fields.to.value : [{type: 'text', text: ''}]
             ]
         } else {
             if (!this.fields.single.value) {
