@@ -1,8 +1,9 @@
 import json
 from django.db import migrations, models, transaction
 
+
 def text_to_json(apps, schema_editor):
-    Document = apps.get_model('document', 'Document')
+    Document = apps.get_model("document", "Document")
     documents = Document.objects.all().iterator()
     with transaction.atomic():
         for document in documents:
@@ -14,15 +15,16 @@ def text_to_json(apps, schema_editor):
                 if field.name == "updated":
                     field.auto_now = False
             document.save()
-    DocumentTemplate = apps.get_model('document', 'DocumentTemplate')
+    DocumentTemplate = apps.get_model("document", "DocumentTemplate")
     templates = DocumentTemplate.objects.all()
     with transaction.atomic():
         for template in templates:
             template.content = json.loads(template.definition)
             template.save()
 
+
 def json_to_text(apps, schema_editor):
-    Document = apps.get_model('document', 'Document')
+    Document = apps.get_model("document", "Document")
     documents = Document.objects.all().iterator()
     with transaction.atomic():
         for document in documents:
@@ -34,74 +36,75 @@ def json_to_text(apps, schema_editor):
                 if field.name == "updated":
                     field.auto_now = False
             document.save()
-    DocumentTemplate = apps.get_model('document', 'DocumentTemplate')
+    DocumentTemplate = apps.get_model("document", "DocumentTemplate")
     templates = DocumentTemplate.objects.all()
     with transaction.atomic():
         for template in templates:
             template.definition = json.dumps(template.content)
             template.save()
 
+
 class Migration(migrations.Migration):
     atomic = False  # to prevent migrations running in single transaction
     dependencies = [
-        ('document', '0003_fidus_3_3'),
+        ("document", "0003_fidus_3_3"),
     ]
 
     operations = [
         migrations.RenameField(
-            model_name='document',
-            old_name='comments',
-            new_name='comments_text'
+            model_name="document",
+            old_name="comments",
+            new_name="comments_text",
         ),
         migrations.AddField(
-            model_name='document',
-            name='comments',
+            model_name="document",
+            name="comments",
             field=models.JSONField(default=dict),
         ),
         migrations.RenameField(
-            model_name='document',
-            old_name='bibliography',
-            new_name='bibliography_text'
+            model_name="document",
+            old_name="bibliography",
+            new_name="bibliography_text",
         ),
         migrations.AddField(
-            model_name='document',
-            name='bibliography',
+            model_name="document",
+            name="bibliography",
             field=models.JSONField(default=dict),
         ),
         migrations.AddField(
-            model_name='document',
-            name='content',
+            model_name="document",
+            name="content",
             field=models.JSONField(default=dict),
         ),
         migrations.AddField(
-            model_name='document',
-            name='diffs',
+            model_name="document",
+            name="diffs",
             field=models.JSONField(default=list),
         ),
         migrations.AddField(
-            model_name='documenttemplate',
-            name='content',
+            model_name="documenttemplate",
+            name="content",
             field=models.JSONField(default=dict),
         ),
         migrations.RunPython(text_to_json, json_to_text),
         migrations.RemoveField(
-            model_name='document',
-            name='comments_text',
+            model_name="document",
+            name="comments_text",
         ),
         migrations.RemoveField(
-            model_name='document',
-            name='bibliography_text',
+            model_name="document",
+            name="bibliography_text",
         ),
         migrations.RemoveField(
-            model_name='document',
-            name='contents',
+            model_name="document",
+            name="contents",
         ),
         migrations.RemoveField(
-            model_name='document',
-            name='last_diffs',
+            model_name="document",
+            name="last_diffs",
         ),
         migrations.RemoveField(
-            model_name='documenttemplate',
-            name='definition',
+            model_name="documenttemplate",
+            name="definition",
         ),
     ]
