@@ -3,7 +3,7 @@ import {importFidusTemplate} from "./templates"
 import {SaveCopy, ExportFidusFile} from "../../exporter/native"
 import {ImportFidusFile} from "../../importer/file"
 import {DocumentRevisionsDialog} from "../revisions"
-import {activateWait, deactivateWait, addAlert, postJson, Dialog, escapeText} from "../../common"
+import {activateWait, deactivateWait, addAlert, postJson, Dialog, escapeText, longFilePath} from "../../common"
 
 export class DocumentOverviewActions {
     constructor(documentOverview) {
@@ -14,30 +14,39 @@ export class DocumentOverviewActions {
     deleteDocument(id) {
         const doc = this.documentOverview.documentList.find(doc => doc.id === id)
         if (!doc) {
-            return
+            return Promise.resolve()
         }
-        postJson(
+        return postJson(
             '/api/document/delete/',
             {id}
         ).then(
             ({json}) => {
                 if (json.done) {
-                    addAlert('success', `${gettext('Document has been deleted')}: '${doc.title}'`)
-                    this.documentOverview.removeTableRows([id])
+                    addAlert('success', `${gettext('Document has been deleted')}: '${longFilePath(doc.title, doc.path)}'`)
                     this.documentOverview.documentList = this.documentOverview.documentList.filter(doc => doc.id !== id)
+                    this.documentOverview.initTable()
                 } else {
-                    addAlert('error', `${gettext('Could not delete document')}: '${doc.title}'`)
+                    addAlert('error', `${gettext('Could not delete document')}: '${longFilePath(doc.title, doc.path)}'`)
                 }
             }
         )
     }
 
     deleteDocumentDialog(ids) {
-
+        const docPaths = ids.map(id => {
+            const doc = this.documentOverview.documentList.find(doc => doc.id === id)
+            return escapeText(longFilePath(doc.title, doc.path))
+        })
         const confirmDeletionDialog = new Dialog({
             title: gettext('Confirm deletion'),
             body: `<p>
-                ${gettext('Delete the document(s)?')}
+                ${  ids.length > 1 ?
+        gettext('Do you really want to delete the following documents?') :
+        gettext('Do you really want to delete the following document?')
+}
+                </p>
+                <p>
+                ${docPaths.join('<br>')}
                 </p>`,
             id: 'confirmdeletion',
             icon: 'exclamation-triangle',
@@ -45,12 +54,15 @@ export class DocumentOverviewActions {
                 {
                     text: gettext('Delete'),
                     classes: "fw-dark",
-                    height: 180,
+                    height: Math.min(50 + 15 * ids.length, 500),
                     click: () => {
-                        for (let i = 0; i < ids.length; i++) {
-                            this.deleteDocument(ids[i])
-                        }
-                        confirmDeletionDialog.close()
+                        Promise.all(ids.map(id => this.deleteDocument(id))).then(
+                            () => {
+                                confirmDeletionDialog.close()
+                                this.documentOverview.initTable()
+                            }
+                        )
+
                     }
                 },
                 {
@@ -82,8 +94,9 @@ export class DocumentOverviewActions {
                     const importer = new ImportFidusFile(
                         fidusFile,
                         this.documentOverview.user,
+                        this.documentOverview.path,
                         true,
-                        this.documentOverview.teamMembers
+                        this.documentOverview.contacts
                     )
 
                     importer.init().then(
@@ -96,11 +109,11 @@ export class DocumentOverviewActions {
                                 return
                             }
                             this.documentOverview.documentList.push(doc)
-                            this.documentOverview.addDocToTable(doc)
+                            this.documentOverview.initTable()
                             importDialog.close()
                         }
                     ).catch(
-                        ()=>false
+                        () => false
                     )
 
                 }
@@ -144,15 +157,15 @@ export class DocumentOverviewActions {
                     const doc = this.documentOverview.documentList.find(entry => entry.id === id)
                     const copier = new SaveCopy(
                         doc,
-                        {db:doc.bibliography},
-                        {db:doc.images},
+                        {db: doc.bibliography},
+                        {db: doc.images},
                         this.documentOverview.user
                     )
 
                     copier.init().then(
                         ({doc}) => {
                             this.documentOverview.documentList.push(doc)
-                            this.documentOverview.addDocToTable(doc)
+                            this.documentOverview.initTable()
                         }
                     ).catch(() => false)
                 })
@@ -187,8 +200,8 @@ export class DocumentOverviewActions {
                                     const doc = this.documentOverview.documentList.find(entry => entry.id === id)
                                     const copier = new SaveCopy(
                                         doc,
-                                        {db:doc.bibliography},
-                                        {db:doc.images},
+                                        {db: doc.bibliography},
+                                        {db: doc.images},
                                         this.documentOverview.user,
                                         selectTemplateDialog.dialogEl.querySelector('select').value
                                     )
@@ -196,7 +209,7 @@ export class DocumentOverviewActions {
                                     copier.init().then(
                                         ({doc}) => {
                                             this.documentOverview.documentList.push(doc)
-                                            this.documentOverview.addDocToTable(doc)
+                                            this.documentOverview.initTable()
                                         }
                                     ).catch(() => false)
                                 })
@@ -223,8 +236,26 @@ export class DocumentOverviewActions {
                 const doc = this.documentOverview.documentList.find(entry => entry.id === id)
                 new ExportFidusFile(
                     doc,
-                    {db:doc.bibliography},
-                    {db:doc.images}
+                    {db: doc.bibliography},
+                    {db: doc.images}
+                )
+            })
+        )
+    }
+
+    downloadSlimNativeFiles(ids) {
+        getMissingDocumentListData(
+            ids,
+            this.documentOverview.documentList,
+            this.documentOverview.schema
+        ).then(
+            () => ids.forEach(id => {
+                const doc = this.documentOverview.documentList.find(entry => entry.id === id)
+                new ExportFidusFile(
+                    doc,
+                    {db: doc.bibliography},
+                    {db: doc.images},
+                    false
                 )
             })
         )
@@ -244,8 +275,8 @@ export class DocumentOverviewActions {
                         this.documentOverview.app.csl,
                         this.documentOverview.documentStyles,
                         doc,
-                        {db:doc.bibliography},
-                        {db:doc.images},
+                        {db: doc.bibliography},
+                        {db: doc.images},
                         new Date(doc.updated * 1000)
                     )
                     exporter.init()
@@ -268,8 +299,8 @@ export class DocumentOverviewActions {
                             const exporter = new DocxExporter(
                                 doc,
                                 templateUrl,
-                                {db:doc.bibliography},
-                                {db:doc.images},
+                                {db: doc.bibliography},
+                                {db: doc.images},
                                 this.documentOverview.app.csl
                             )
                             exporter.init()
@@ -279,8 +310,8 @@ export class DocumentOverviewActions {
                             const exporter = new OdtExporter(
                                 doc,
                                 templateUrl,
-                                {db:doc.bibliography},
-                                {db:doc.images},
+                                {db: doc.bibliography},
+                                {db: doc.images},
                                 this.documentOverview.app.csl
                             )
                             exporter.init()
@@ -303,8 +334,8 @@ export class DocumentOverviewActions {
                     import("../../exporter/latex").then(({LatexExporter}) => {
                         const exporter = new LatexExporter(
                             doc,
-                            {db:doc.bibliography},
-                            {db:doc.images},
+                            {db: doc.bibliography},
+                            {db: doc.images},
                             new Date(doc.updated * 1000)
                         )
                         exporter.init()
@@ -325,8 +356,8 @@ export class DocumentOverviewActions {
                     import("../../exporter/jats").then(({JATSExporter}) => {
                         const exporter = new JATSExporter(
                             doc,
-                            {db:doc.bibliography},
-                            {db:doc.images},
+                            {db: doc.bibliography},
+                            {db: doc.images},
                             this.documentOverview.app.csl,
                             new Date(doc.updated * 1000)
                         )
@@ -351,8 +382,8 @@ export class DocumentOverviewActions {
                             this.documentOverview.app.csl,
                             this.documentOverview.documentStyles,
                             doc,
-                            {db:doc.bibliography},
-                            {db:doc.images},
+                            {db: doc.bibliography},
+                            {db: doc.images},
                             new Date(doc.updated * 1000)
                         )
                         exporter.init()
@@ -372,12 +403,11 @@ export class DocumentOverviewActions {
                 switch (actionObject.action) {
                 case 'added-document':
                     this.documentOverview.documentList.push(actionObject.doc)
-                    this.documentOverview.addDocToTable(actionObject.doc)
+                    this.documentOverview.initTable()
                     break
                 case 'deleted-revision':
                     actionObject.doc.revisions = actionObject.doc.revisions.filter(rev => rev.pk !== actionObject.id)
-                    this.documentOverview.removeTableRows([actionObject.doc.id])
-                    this.documentOverview.addDocToTable(actionObject.doc)
+                    this.documentOverview.initTable()
                     break
                 }
             })
