@@ -316,7 +316,7 @@ export class Merge {
             id: "merge_failed",
             body: gettext('An error occurred during the merge process, so we cannot save your work to the server any longer, and it is downloaded to your computer instead. Please consider importing it into a new document.'),
             buttons: [{
-                text: gettext('Proceed to dashboard'),
+                text: gettext('Leave editor'),
                 classes: 'fw-dark',
                 click: () => {
                     window.location.href = '/'
