@@ -3,6 +3,8 @@ import {CommentEditor} from "./comment"
 export class CommentAnswerEditor extends CommentEditor {
     constructor(mod, id, dom, text, options = {}) {
         super(mod, id, dom, text, options)
+
+        this.keepOpenAfterSubmit = true
     }
 
     initViewDOM() {
@@ -12,7 +14,7 @@ export class CommentAnswerEditor extends CommentEditor {
         this.dom.insertAdjacentHTML(
             'beforeend',
             `<div class="comment-btns">
-                <button class="submit fw-button fw-dark" type="submit">
+                <button class="submit fw-button fw-dark disabled" type="submit">
                     ${this.options.answerId ? gettext("Edit") : gettext("Submit")}
                 </button>
                 <button class="cancel fw-button fw-orange" type="submit">
