@@ -129,14 +129,14 @@ import {
 
 export const COMMENT_ONLY_ROLES = ['review', 'comment']
 export const READ_ONLY_ROLES = ['read', 'read-without-comments']
-export const REVIEW_ROLES = ['review']
-export const WRITE_ROLES = ['write', 'write-tracked']
+export const REVIEW_ROLES = ['review', 'review-tracked']
+export const WRITE_ROLES = ['write', 'write-tracked', 'review-tracked']
 
 export class Editor {
     // A class that contains everything that happens on the editor page.
     // It is currently not possible to initialize more than one editor class, as it
     // contains bindings to menu items, etc. that are uniquely defined.
-    constructor({app, user}, idString) {
+    constructor({app, user}, path, idString) {
         this.app = app
         this.user = user
         this.mod = {}
@@ -151,7 +151,8 @@ export class Editor {
             is_owner: false,
             confirmedDoc: false, // The latest doc as confirmed by the server.
             updated: false, // Latest update time stamp
-            dir: 'ltr' // standard direction, used in input fields, etc.
+            dir: 'ltr', // standard direction, used in input fields, etc.
+            path // Default doc path.
         }
         let id = parseInt(idString)
         if (isNaN(id)) {
@@ -180,6 +181,8 @@ export class Editor {
         this.client_id = Math.floor(Math.random() * 0xFFFFFFFF)
         this.clientTimeAdjustment = 0
 
+        this.pathEditable = true // Set to false through plugin to disable path editing.
+
         this.statePlugins = [
             [keymap, () => buildEditorKeymap(this.schema)],
             [keymap, () => buildKeymap(this.schema)],
@@ -244,7 +247,13 @@ export class Editor {
         ]
         if (this.docInfo.hasOwnProperty('templateId')) {
             initPromises.push(
-                postJson(`/api/document/create_doc/${this.docInfo.templateId}/`).then(
+                postJson(
+                    '/api/document/create_doc/',
+                    {
+                        template_id: this.docInfo.templateId,
+                        path: this.docInfo.path
+                    }
+                ).then(
                     ({json}) => {
                         this.docInfo.id = json.id
                         window.history.replaceState("", "", `/document/${this.docInfo.id}/`)
@@ -321,6 +330,10 @@ export class Editor {
                         }
                         this.mod.collab.doc.receiveSelectionChange(data)
                         break
+                    case 'path_change':
+                        this.docInfo.path = data["path"]
+                        this.menu.headerView.update()
+                        break
                     case 'diff':
                         if (data["cid"] === this.client_id) {
                             // The diff origins from the local user.
@@ -421,7 +434,7 @@ export class Editor {
             id: "access_rights_modified",
             body: gettext('Your access rights were modified while you were offline, so we cannot save your work to the server any longer, and it is downloaded to your computer instead. Please consider importing it into a new document.'),
             buttons: [{
-                text: gettext('Proceed to dashboard'),
+                text: gettext('Leave editor'),
                 classes: 'fw-dark',
                 click: () => {
                     window.location.href = '/'
@@ -505,6 +518,7 @@ export class Editor {
             showSystemMessage(gettext("Changes you made to the document since going offline will be lost, if you choose to close/refresh the tab or close the browser."))
             return true
         }
+        this.close()
     }
 
     initEditor() {
@@ -592,6 +606,7 @@ export class Editor {
             content: pmArticle.toJSON(),
             settings: getSettings(pmArticle),
             title: title.substring(0, 255),
+            path: this.docInfo.path,
             version: this.docInfo.version,
             comments: this.mod.comments.store.comments,
             id: this.docInfo.id,
@@ -652,4 +667,12 @@ export class Editor {
         return
     }
 
+    scrollBibliographyIntoView() {
+        const topMenuHeight = this.dom.querySelector('header').offsetHeight + 10
+        const bibliographyHeaderEl = document.querySelector('h1.article-bibliography-header')
+        const distanceFromTop = bibliographyHeaderEl.getBoundingClientRect().top - topMenuHeight
+        window.scrollBy({left: 0, top: distanceFromTop, behavior: "smooth", block: "center"})
+        return
+    }
+
 }
