@@ -105,17 +105,17 @@ const commentTemplate = ({comment, view, active, editComment, activeCommentAnswe
         !filterOptions.comments ||
         (filterOptions.commentsOnlyMajor && !comment.isMajor) ||
         (!filterOptions.commentsResolved && comment.resolved) ||
-        (filterOptions.author && comment.user !== filterOptions.author) ||
+        (filterOptions.commentsAuthor && comment.user !== filterOptions.commentsAuthor) ||
         (filterOptions.assigned && comment.assignedUser !== filterOptions.assigned) ||
         comment.hidden
     ) {
         return '<div class="margin-box comment hidden"></div>'
     }
-    const author = comment.user === docInfo.owner.id ? docInfo.owner : docInfo.owner.team_members.find(member => member.id === comment.user),
+    const author = comment.user === docInfo.owner.id ? docInfo.owner : docInfo.owner.contacts.find(contact => contact.id === comment.user),
         assignedUser = comment.assignedUser ?
             comment.assignedUser === docInfo.owner.id ?
                 docInfo.owner :
-                docInfo.owner.team_members.find(member => member.id === comment.assignedUser)  ||
+                docInfo.owner.contacts.find(contact => contact.id === comment.assignedUser)  ||
                 {
                     name: comment.assignedUsername || ''
                 } :
@@ -124,7 +124,7 @@ const commentTemplate = ({comment, view, active, editComment, activeCommentAnswe
     return `
         <div id="margin-box-${comment.id}" data-view="${view}" data-id="${comment.id}" data-user-id="${comment.user}"
             class="margin-box comment ${active ? 'active' : 'inactive'} ${comment.resolved ? 'resolved' : ''} ${comment.isMajor === true ? 'comment-is-major-bgc' : ''}">
-<div class="comment-answer-container">    
+<div class="comment-answer-container">
 ${
     comment.comment.length === 0 ?
         firstCommentTemplate({comment, author}) :
@@ -140,7 +140,7 @@ ${
         comment.answers.map(answer =>
             answerCommentTemplate({
                 answer,
-                author: answer.user === docInfo.owner.id ? docInfo.owner : docInfo.owner.team_members.find(member => member.id === answer.user),
+                author: answer.user === docInfo.owner.id ? docInfo.owner : docInfo.owner.contacts.find(contact => contact.id === answer.user),
                 commentId: comment.id,
                 active,
                 activeCommentAnswerId,
@@ -235,11 +235,14 @@ const BLOCK_NAMES = {
 const blockChangeTemplate = ({before}, node) => `<div class="format-change-info"><b>${gettext('Was')}:</b> ${BLOCK_NAMES[before.type]}${before.type === 'ordered_list' && node.type.name === 'ordered_list' ? `, ${gettext('start')}: ${before.attrs.order}` : ''}</div>`
 
 const trackTemplate = ({type, data, node, active, docInfo, filterOptions}) => {
-    if (!filterOptions.track) {
+    if (
+        !filterOptions.track ||
+        (filterOptions.trackAuthor && data.user !== filterOptions.trackAuthor)
+    ) {
         return '<div class="margin-box track hidden"></div>'
     }
 
-    const author = data.user === docInfo.owner.id ? docInfo.owner : docInfo.owner.team_members.find(member => member.id === data.user),
+    const author = data.user === docInfo.owner.id ? docInfo.owner : docInfo.owner.contacts.find(contact => contact.id === data.user),
         nodeActionType = `${type}_${node.type.name}`
 
     return `
@@ -266,7 +269,7 @@ const trackTemplate = ({type, data, node, active, docInfo, filterOptions}) => {
         </div>`
 }
 
-export const marginboxFilterTemplate = ({marginBoxes, filterOptions, docInfo}) => {
+export const marginboxFilterTemplate = ({marginBoxes, filterOptions, pastParticipants}) => {
     const comments = marginBoxes.find(box => box.type === 'comment')
     const tracks = marginBoxes.find(box => ['insertion', 'deletion', 'format_change', 'block_change'].includes(box.type))
     const help = marginBoxes.find(box => box.type === 'help')
@@ -284,12 +287,12 @@ export const marginboxFilterTemplate = ({marginBoxes, filterOptions, docInfo}) =
                     </span>
                     <div class="fw-pulldown marginbox-options-submenu">
                         <ul>
-                            <li><span class="fw-pulldown-item margin-box-filter-comments-author${filterOptions.author === 0 ? ' selected' : ''}" data-id="0" title="${gettext('Show comments from all authors.')}">
+                            <li><span class="fw-pulldown-item margin-box-filter-comments-author${filterOptions.commentsAuthor === 0 ? ' selected' : ''}" data-id="0" title="${gettext('Show comments from all authors.')}">
                                 ${gettext('Any')}
                             </span></li>
                         ${
-    docInfo.owner.team_members.concat(docInfo.owner).map(
-        user => `<li><span class="fw-pulldown-item margin-box-filter-comments-author${filterOptions.author === user.id ? ' selected' : ''}" data-id="${user.id}" title="${gettext('Show comments of ')} ${escapeText(user.name)}">
+    pastParticipants.map(
+        user => `<li><span class="fw-pulldown-item margin-box-filter-comments-author${filterOptions.commentsAuthor === user.id ? ' selected' : ''}" data-id="${user.id}" title="${gettext('Show comments of ')} ${escapeText(user.name)}">
                                     ${escapeText(user.name)}
                                 </span></li>`
     ).join('')
@@ -308,7 +311,7 @@ export const marginboxFilterTemplate = ({marginBoxes, filterOptions, docInfo}) =
                                 ${gettext('Any/None')}
                             </span></li>
                         ${
-    docInfo.owner.team_members.concat(docInfo.owner).map(
+    pastParticipants.map(
         user => `<li><span class="fw-pulldown-item margin-box-filter-comments-assigned${filterOptions.assigned === user.id ? ' selected' : ''}" data-id="${user.id}" title="${gettext('Show comments of ')} ${escapeText(user.name)}">
                                     ${escapeText(user.name)}
                                 </span></li>`
@@ -334,7 +337,29 @@ export const marginboxFilterTemplate = ({marginBoxes, filterOptions, docInfo}) =
     }
     if (tracks) {
         filterHTML += `<div id="margin-box-filter-track" class="margin-box-filter-button${filterOptions.track ? '' : ' disabled'}">
-            <span class="label">${gettext('Track changes')}</span>
+            <span class="label">${gettext('Tracking')}</span><span class="show-marginbox-options fa fa-ellipsis-v"></span>
+            <div class="marginbox-options fw-pulldown fw-right"><ul>
+                <li>
+                    <span class="fw-pulldown-item show-marginbox-options-submenu" title="${gettext('Author')}">
+                        ${gettext('Author')}
+                        <span class="fw-icon-right"><i class="fa fa-caret-right"></i></span>
+                    </span>
+                    <div class="fw-pulldown marginbox-options-submenu">
+                        <ul>
+                            <li><span class="fw-pulldown-item margin-box-filter-track-author${filterOptions.trackAuthor === 0 ? ' selected' : ''}" data-id="0" title="${gettext('Show track changes from all authors.')}">
+                                ${gettext('Any')}
+                            </span></li>
+                        ${
+    pastParticipants.map(
+        user => `<li><span class="fw-pulldown-item margin-box-filter-track-author${filterOptions.trackAuthor === user.id ? ' selected' : ''}" data-id="${user.id}" title="${gettext('Show track changes of ')} ${escapeText(user.name)}">
+                                    ${escapeText(user.name)}
+                                </span></li>`
+    ).join('')
+}
+                        </ul>
+                    </div>
+                </li>
+            </ul></div>
         </div>`
     }
     if (help || warning) {
@@ -429,7 +454,7 @@ export const marginBoxOptions = (comment, user, docInfo) => {
                         <ul>
                             <li><span class="fw-pulldown-item unassign-comment" data-id="${comment.id}" title="${gettext('Remove user assignment from comment')}">${gettext('No-one')}</span></li>
                         ${
-    docInfo.owner.team_members.concat(docInfo.owner).map(
+    docInfo.owner.contacts.concat(docInfo.owner).map(
         user => `<li><span class="fw-pulldown-item assign-comment" data-id="${comment.id}" data-user="${user.id}" data-username="${escapeText(user.name)}" title="${gettext('Assign comment to')} ${escapeText(user.name)}">${escapeText(user.name)}</span></li>`
     ).join('')
 }
