@@ -47,15 +47,15 @@ export const headerbarModel = () => ({
                     action: editor => {
                         const dialog = new DocumentAccessRightsDialog(
                             [editor.docInfo.id],
-                            editor.docInfo.owner.team_members,
-                            memberData => {
-                                editor.docInfo.owner.team_members.push(memberData)
+                            editor.docInfo.owner.contacts,
+                            contactData => {
+                                editor.docInfo.owner.contacts.push(contactData)
                             }
                         )
                         dialog.init()
                     },
                     disabled: editor => {
-                        return !editor.docInfo.is_owner
+                        return !editor.docInfo.is_owner || editor.app.isOffline()
                     }
                 },
                 {
@@ -65,14 +65,23 @@ export const headerbarModel = () => ({
                     tooltip: gettext('Close the document and return to the document overview menu.'),
                     order: 1,
                     action: editor => {
-                        editor.app.goTo('/')
-                    }
+                        const folderPath = editor.docInfo.path.slice(
+                            0,
+                            editor.docInfo.path.lastIndexOf('/')
+                        )
+                        if (!folderPath.length) {
+                            editor.app.goTo('/')
+                        } else {
+                            editor.app.goTo(`/documents${folderPath}/`)
+                        }
+                    },
+                    disabled: editor => editor.app.isOffline()
                 },
                 {
                     title: gettext('Save revision'),
                     type: 'action',
                     //icon: 'save',
-                    tooltip: gettext('Save a revision of the current document.'),
+                    tooltip: gettext('Save a revision of the document.'),
                     order: 2,
                     keys: 'Ctrl-s',
                     action: editor => {
@@ -83,19 +92,20 @@ export const headerbarModel = () => ({
                                     editor.getDoc(),
                                     editor.mod.db.imageDB,
                                     editor.mod.db.bibDB,
-                                    note
+                                    note,
+                                    editor.app
                                 )
                                 return saver.init()
                             }
                         )
                     },
-                    disabled: editor => editor.docInfo.access_rights !== 'write'
+                    disabled: editor => editor.docInfo.access_rights !== 'write' || editor.app.isOffline()
                 },
                 {
                     title: gettext('Create copy'),
                     type: 'action',
                     //icon: 'copy',
-                    tooltip: gettext('Create copy of the current document.'),
+                    tooltip: gettext('Create a copy of the document.'),
                     order: 3,
                     action: editor => {
                         const copier = new SaveCopy(
@@ -107,13 +117,14 @@ export const headerbarModel = () => ({
                         copier.init().then(({docInfo}) =>
                             editor.app.goTo(`/document/${docInfo.id}/`)
                         ).catch(() => false)
-                    }
+                    },
+                    disabled: editor => editor.app.isOffline(),
                 },
                 {
                     title: gettext('Download'),
                     type: 'action',
                     //icon: 'download',
-                    tooltip: gettext('Download the current document.'),
+                    tooltip: gettext('Export the document as a FIDUS file including its template.'),
                     order: 4,
                     action: editor => {
                         new ExportFidusFile(
@@ -121,7 +132,8 @@ export const headerbarModel = () => ({
                             editor.mod.db.bibDB,
                             editor.mod.db.imageDB
                         )
-                    }
+                    },
+                    disabled: editor => editor.app.isOffline(),
                 },
                 {
                     title: gettext('Print/PDF'),
@@ -191,7 +203,8 @@ export const headerbarModel = () => ({
                             )
                             exporter.init()
                         })
-                    }
+                    },
+                    disabled: editor => editor.app.isOffline()
                 },
                 {
                     title: gettext('LaTeX'),
@@ -208,7 +221,8 @@ export const headerbarModel = () => ({
                             )
                             exporter.init()
                         })
-                    }
+                    },
+                    disabled: editor => editor.app.isOffline()
                 },
                 {
                     title: gettext('JATS'),
@@ -226,8 +240,23 @@ export const headerbarModel = () => ({
                             )
                             exporter.init()
                         })
+                    },
+                    disabled: editor => editor.app.isOffline()
+                },
+                {
+                    title: gettext('Slim FIDUS'),
+                    type: 'action',
+                    tooltip: gettext('Export the document to a FIDUS file without its template.'),
+                    order: 3,
+                    action: editor => {
+                        new ExportFidusFile(
+                            editor.getDoc(),
+                            editor.mod.db.bibDB,
+                            editor.mod.db.imageDB,
+                            false
+                        )
                     }
-                }
+                },
             ]
         },
         {
@@ -255,7 +284,7 @@ export const headerbarModel = () => ({
                     tooltip: gettext('Choose your preferred document style.'),
                     order: 2,
                     disabled: editor => {
-                        return editor.docInfo.access_rights !== 'write'
+                        return editor.docInfo.access_rights !== 'write' || editor.app.isOffline()
                     },
                     content: []
                 },
@@ -277,10 +306,10 @@ export const headerbarModel = () => ({
                         languageItem('fr', gettext('French'), 5),
                         languageItem('ja', gettext('Japanese'), 6),
                         languageItem('it', gettext('Italian'), 7),
-                        languageItem('pl', gettext('Polish'), 8),
+                        //languageItem('pl', gettext('Polish'), 8),
                         languageItem('pt-BR', gettext('Portuguese (Brazil)'), 9),
-                        languageItem('nl', gettext('Dutch'), 10),
-                        languageItem('ru', gettext('Russian'), 11),
+                        //languageItem('nl', gettext('Dutch'), 10),
+                        //languageItem('ru', gettext('Russian'), 11),
                         {
                             type: 'separator',
                             order: 12,
@@ -439,9 +468,7 @@ export const headerbarModel = () => ({
                             }
                         )
                     },
-                    disabled: editor => {
-                        return editor.docInfo.access_rights !== 'write'
-                    }
+                    disabled: editor => editor.docInfo.access_rights !== 'write'
                 }
             ]
         },
@@ -491,9 +518,7 @@ export const headerbarModel = () => ({
             type: 'menu',
             tooltip: gettext('Tracking changes to the document'),
             order: 4,
-            disabled: editor => {
-                return editor.docInfo.access_rights !== 'write'
-            },
+            disabled: editor => editor.docInfo.access_rights !== 'write',
             content: [
                 {
                     title: gettext('Record'),
