@@ -6,7 +6,6 @@ from selenium.webdriver.support import expected_conditions as EC
 
 
 class SendFeedbackTest(LiveTornadoTestCase, SeleniumHelper):
-
     @classmethod
     def setUpClass(cls):
         super().setUpClass()
@@ -26,9 +25,7 @@ class SendFeedbackTest(LiveTornadoTestCase, SeleniumHelper):
         self.verificationErrors = []
         self.accept_next_alert = True
         self.user = self.create_user(
-            username='Yeti',
-            email='yeti@snowman.com',
-            passtext='otter1'
+            username="Yeti", email="yeti@snowman.com", passtext="otter1"
         )
 
     def test_sendfeedback(self):
@@ -40,28 +37,18 @@ class SendFeedbackTest(LiveTornadoTestCase, SeleniumHelper):
         )
         self.driver.find_element(By.ID, "feedbackbutton").click()
         WebDriverWait(self.driver, self.wait_time).until(
-            EC.element_to_be_clickable(
-                (
-                    By.ID,
-                    "response-message"
-                )
-            )
+            EC.element_to_be_clickable((By.ID, "response-message"))
+        )
+        assert (
+            self.driver.find_element(By.ID, "response-message").text
+            == "Thank you for your report!"
         )
-        assert self.driver.find_element(
-            By.ID,
-            "response-message"
-        ).text == "Thank you for your report!"
         self.driver.find_element(By.ID, "closeFeedback").click()
         self.driver.find_element(By.ID, "id_login").send_keys("Yeti")
         self.driver.find_element(By.ID, "id_password").send_keys("otter1")
         self.driver.find_element(By.ID, "login-submit").click()
         WebDriverWait(self.driver, self.wait_time).until(
-            EC.presence_of_element_located(
-                (
-                    By.ID,
-                    "preferences-btn"
-                )
-            )
+            EC.presence_of_element_located((By.ID, "preferences-btn"))
         )
         self.driver.find_element(By.CSS_SELECTOR, ".feedback-tab").click()
         self.driver.find_element(By.ID, "message").click()
@@ -70,17 +57,12 @@ class SendFeedbackTest(LiveTornadoTestCase, SeleniumHelper):
         )
         self.driver.find_element(By.ID, "feedbackbutton").click()
         WebDriverWait(self.driver, self.wait_time).until(
-            EC.element_to_be_clickable(
-                (
-                    By.ID,
-                    "response-message"
-                )
-            )
+            EC.element_to_be_clickable((By.ID, "response-message"))
+        )
+        assert (
+            self.driver.find_element(By.ID, "response-message").text
+            == "Thank you for your report!"
         )
-        assert self.driver.find_element(
-            By.ID,
-            "response-message"
-        ).text == "Thank you for your report!"
         self.driver.find_element(By.ID, "closeFeedback").click()
         self.driver.find_element(By.ID, "preferences-btn").click()
         self.driver.find_element_by_xpath(
