@@ -2,5 +2,5 @@ from django.conf.urls import url
 from . import views
 
 urlpatterns = [
-    url('^feedback/$', views.feedback, name='feedback'),
+    url("^feedback/$", views.feedback, name="feedback"),
 ]
