@@ -12,8 +12,8 @@ from testing.selenium_helper import SeleniumHelper
 
 class ContactsTest(LiveTornadoTestCase, SeleniumHelper):
     fixtures = [
-        'initial_documenttemplates.json',
-        'initial_styles.json',
+        "initial_documenttemplates.json",
+        "initial_styles.json",
     ]
 
     @classmethod
@@ -33,19 +33,17 @@ class ContactsTest(LiveTornadoTestCase, SeleniumHelper):
 
     def setUp(self):
         self.user = self.create_user(
-            username='Yeti',
-            email='yeti@snowman.com',
-            passtext='password'
+            username="Yeti", email="yeti@snowman.com", passtext="password"
         )
         self.contact1 = self.create_user(
-            username='Contact1',
-            email='contact1@snowman.com',
-            passtext='password'
+            username="Contact1",
+            email="contact1@snowman.com",
+            passtext="password",
         )
         self.contact2 = self.create_user(
-            username='Contact2',
-            email='contact2@snowman.com',
-            passtext='password'
+            username="Contact2",
+            email="contact2@snowman.com",
+            passtext="password",
         )
         self.login_user(self.user, self.driver, self.client)
 
@@ -53,108 +51,93 @@ class ContactsTest(LiveTornadoTestCase, SeleniumHelper):
         self.driver.get(self.base_url + "/")
         WebDriverWait(self.driver, self.wait_time).until(
             EC.element_to_be_clickable(
-                (
-                    By.CSS_SELECTOR,
-                    ".new_document button"
-                )
+                (By.CSS_SELECTOR, ".new_document button")
             )
         ).click()
         WebDriverWait(self.driver, self.wait_time).until(
-            EC.presence_of_element_located((By.CLASS_NAME, 'editor-toolbar'))
+            EC.presence_of_element_located((By.CLASS_NAME, "editor-toolbar"))
         )
         # Open share dialog
         self.driver.find_element(
-            By.CSS_SELECTOR,
-            ".header-menu:nth-child(1) > .header-nav-item"
+            By.CSS_SELECTOR, ".header-menu:nth-child(1) > .header-nav-item"
         ).click()
         self.driver.find_element(
-            By.CSS_SELECTOR,
-            "li:nth-child(1) > .fw-pulldown-item"
+            By.CSS_SELECTOR, "li:nth-child(1) > .fw-pulldown-item"
         ).click()
         self.driver.find_element(
-            By.CSS_SELECTOR,
-            ".ui-dialog .fw-add-button"
+            By.CSS_SELECTOR, ".ui-dialog .fw-add-button"
         ).click()
-        self.driver.find_element(
-            By.ID,
-            "new-member-user-string"
-        ).click()
-        self.driver.find_element(By.ID, "new-member-user-string").send_keys(
+        self.driver.find_element(By.ID, "new-contact-user-string").click()
+        self.driver.find_element(By.ID, "new-contact-user-string").send_keys(
             "contact1@snowman.com"
         )
-        ActionChains(self.driver).send_keys(
-            Keys.TAB
-        ).send_keys(
+        ActionChains(self.driver).send_keys(Keys.TAB).send_keys(
             Keys.RETURN
         ).perform()
         self.driver.find_element(
-            By.CSS_SELECTOR,
-            ".ui-dialog .fw-dark"
+            By.CSS_SELECTOR, ".ui-dialog .fw-dark"
         ).click()
         # Close document
-        self.driver.find_element(
-            By.ID,
-            "close-document-top"
-        ).click()
+        self.driver.find_element(By.ID, "close-document-top").click()
         # Enter contacts page
         WebDriverWait(self.driver, self.wait_time).until(
-            EC.element_to_be_clickable((By.ID, 'preferences-btn'))
+            EC.element_to_be_clickable((By.ID, "preferences-btn"))
         ).click()
         self.driver.find_element_by_xpath(
             '//*[normalize-space()="Contacts"]'
         ).click()
         self.assertEqual(
-            len(self.driver.find_elements_by_css_selector(
-                '#team-table .entry-select'
-            )),
-            1
+            len(
+                self.driver.find_elements_by_css_selector(
+                    ".contacts-table .entry-select"
+                )
+            ),
+            1,
         )
         self.driver.find_element_by_css_selector(
-            "button[title='Add new contact']"
-        ).click()
-        self.driver.find_element_by_id(
-            "new-member-user-string"
-        ).send_keys('contact2@snowman.com')
-        self.driver.find_element_by_css_selector(
-            "button.fw-dark"
+            "button[title='Invite contact']"
         ).click()
+        self.driver.find_element_by_id("new-contact-user-string").send_keys(
+            "contact2@snowman.com"
+        )
+        self.driver.find_element_by_css_selector("button.fw-dark").click()
         time.sleep(1)
         self.assertEqual(
-            len(self.driver.find_elements_by_css_selector(
-                '#team-table .entry-select'
-            )),
-            2
+            len(
+                self.driver.find_elements_by_css_selector(
+                    ".contacts-table .entry-select"
+                )
+            ),
+            2,
         )
         # Delete individual
         self.driver.find_element_by_css_selector(
-            ".delete-single-member"
-        ).click()
-        self.driver.find_element_by_css_selector(
-            "button.fw-dark"
+            ".delete-single-contact"
         ).click()
+        self.driver.find_element_by_css_selector("button.fw-dark").click()
         time.sleep(1)
         self.assertEqual(
-            len(self.driver.find_elements_by_css_selector(
-                '#team-table .entry-select'
-            )),
-            1
+            len(
+                self.driver.find_elements_by_css_selector(
+                    ".contacts-table .entry-select"
+                )
+            ),
+            1,
         )
         self.driver.find_element_by_css_selector(
-            "#team-table td:nth-child(1) > label"
-        ).click()
-        self.driver.find_element_by_css_selector(
-            ".dt-bulk-dropdown"
+            ".contacts-table td:nth-child(1) > label"
         ).click()
+        self.driver.find_element_by_css_selector(".dt-bulk-dropdown").click()
         self.driver.find_element_by_css_selector(
             "li[title='Delete selected contacts.']"
         ).click()
-        self.driver.find_element_by_css_selector(
-            "button.fw-dark"
-        ).click()
+        self.driver.find_element_by_css_selector("button.fw-dark").click()
         time.sleep(1)
         self.assertEqual(
-            len(self.driver.find_elements_by_css_selector(
-                '#team-table .entry-select'
-            )),
-            0
+            len(
+                self.driver.find_elements_by_css_selector(
+                    ".contacts-table .entry-select"
+                )
+            ),
+            0,
         )
