@@ -7,8 +7,15 @@ export const menuModel = () => ({
             title: gettext('Create new document template'),
             action: overview => {
                 overview.app.goTo('/templates/0/')
-            }
-        }
+            },
+            order: 1
+        },
+        {
+            type: 'text',
+            title: gettext('Upload FIDUSTEMPLATE file'),
+            action: overview => overview.mod.actions.uploadDocTemplate(),
+            order: 2
+        },
     ]
 })
 
@@ -44,6 +51,17 @@ export const bulkMenuModel = () => ({
                 )
             },
             disabled: overview => !overview.getSelected().length
+        },
+        {
+            title: gettext('Download selected'),
+            tooltip: gettext('Download selected document templates.'),
+            action: overview => {
+                const ids = overview.getSelected()
+                ids.forEach(id =>
+                    overview.mod.actions.downloadDocTemplate(id)
+                )
+            },
+            disabled: overview => !overview.getSelected().length
         }
     ]
 })
